@@ -19,7 +19,7 @@
         <translation>Profil:</translation>
     </message>
     <message>
-        <location filename="../cardwidget.cc" line="68"/>
+        <location filename="../cardwidget.cc" line="67"/>
         <source>pa_context_set_card_profile_by_index() failed</source>
         <translation>volání funkce pa_context_set_card_profile_by_index() neproběhlo úspěšně</translation>
     </message>
@@ -41,7 +41,7 @@
     <message>
         <location filename="../channel.cc" line="160"/>
         <source>&lt;small&gt;Silence&lt;/small&gt;</source>
-        <translation>&lt;small&gt;Ticho&lt;/small&gt;</translation>
+        <translation>&lt;small&gt;Ztišit&lt;/small&gt;</translation>
     </message>
     <message>
         <location filename="../channel.cc" line="160"/>
@@ -325,48 +325,48 @@
     </message>
     <message>
         <location filename="../mainwindow.cc" line="163"/>
-        <location filename="../mainwindow.cc" line="258"/>
+        <location filename="../mainwindow.cc" line="257"/>
         <source> (unavailable)</source>
         <translation> (nedostupné)</translation>
     </message>
     <message>
         <location filename="../mainwindow.cc" line="165"/>
-        <location filename="../mainwindow.cc" line="255"/>
+        <location filename="../mainwindow.cc" line="254"/>
         <source> (unplugged)</source>
         <translation> (vypojeno)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="389"/>
+        <location filename="../mainwindow.cc" line="388"/>
         <source>Failed to read data from stream</source>
         <translation>Nepodařilo se přečíst data z proudu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="433"/>
+        <location filename="../mainwindow.cc" line="432"/>
         <source>Peak detect</source>
         <translation>Rozpoznávání špiček</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="434"/>
+        <location filename="../mainwindow.cc" line="433"/>
         <source>Failed to create monitoring stream</source>
         <translation>Nepodařilo se vytvořit sledovací proud</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="449"/>
+        <location filename="../mainwindow.cc" line="448"/>
         <source>Failed to connect monitoring stream</source>
         <translation>Nepodařilo se připojit sledovací proud</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="588"/>
+        <location filename="../mainwindow.cc" line="587"/>
         <source>Ignoring sink-input due to it being designated as an event and thus handled by the Event widget</source>
         <translation>Ignoruje se vstup do odchodu protože je označen jako událost a proto obsloužen ovládacím prvkem pro události</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="760"/>
+        <location filename="../mainwindow.cc" line="759"/>
         <source>System Sounds</source>
         <translation>Systémové zvuky</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="1090"/>
+        <location filename="../mainwindow.cc" line="1089"/>
         <source>Establishing connection to PulseAudio. Please wait...</source>
         <translation>Navazuje se spojení s PulseAudio. Čekejte…</translation>
     </message>
@@ -538,19 +538,19 @@ run start-pulseaudio-x11 manually.</source>
 
 V tomto případě je to nejspíš proto, že je chybně nastavená proměnná PULSE_SERVER v
 Prostředí/Vlastnosti X11 kořenového okna nebo je v client.conf chybně nastaven parametr default-server.
-Tato situace také může nastat když PulseAudio spadne a zanechá visící podrobnosti v kořenovém okně X11.
+Tato situace také může nastat když PulseAudio zhavaruje a zanechá staré údaje v kořenovém okně X11.
 Pokud tomu je tak, PulseAudio by se mělo automaticky znovu spustit, nebo pokud tak není nastavené,
 je třeba ručně spustit start-pulseaudio-x11.</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="672"/>
         <source>Select a specific tab on load.</source>
-        <translation>Při načítání vybrat konkrétní kartu.</translation>
+        <translation>Při načítání vybrat konkrétní panel.</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="675"/>
         <source>Retry forever if pa quits (every 5 seconds).</source>
-        <translation>Pokud PulseAudio skončí, opakovat pořád (každých 5 sekund).</translation>
+        <translation>Pokud PulseAudio skončí, opakovat neustále (každých 5 sekund).</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="678"/>
@@ -576,7 +576,7 @@ je třeba ručně spustit start-pulseaudio-x11.</translation>
     <message>
         <location filename="../sinkinputwidget.cc" line="36"/>
         <source>on</source>
-        <translation>zapnuto</translation>
+        <translation>na</translation>
     </message>
     <message>
         <location filename="../sinkinputwidget.cc" line="39"/>
@@ -640,7 +640,7 @@ je třeba ručně spustit start-pulseaudio-x11.</translation>
 <context>
     <name>SourceOutputWidget</name>
     <message>
-        <location filename="../sourceoutputwidget.cc" line="36"/>
+        <location filename="../sourceoutputwidget.cc" line="35"/>
         <source>from</source>
         <translation>z</translation>
     </message>
